@@ -214,39 +214,28 @@ class anim_text:
         bpy.ops.object.text_add()
         ob=bpy.context.object
         ob.data.body = "INIT"
-        ob.name = name+'_text'
 
         self.obj = ob
 
         self.obj.parent = parent
         self.name = name
 
-        end_frames = anim.frames[-1]
 
         if not(if_str):
             def update(self):
                 text = ob
                 cur_frame = bpy.context.scene.frame_current
                 
-                if np.any(cur_frame == anim.frames):
-                    ind = np.where(cur_frame == anim.frames)[0][0]
-                    text.data.body = ('{0:.'+str(fix_place)+'f}').format(data[ind]) + ' ' + label
-                else:
-                    ind = np.where((cur_frame - anim.frames) == min(cur_frame - anim.frames))[0][0]
-                    text.data.body = ('{0:.'+str(fix_place)+'f}').format(data[ind]) + ' ' + label
+                ind = np.where(abs(cur_frame - anim.frames)  == min(abs(cur_frame - anim.frames)))[0][0]
+                text.data.body = ('{0:.'+str(fix_place)+'f}').format(data[ind]) + ' ' + label
                     
         else:
             def update(self):
                 text = ob
                 cur_frame = bpy.context.scene.frame_current
                 
-                if np.any(cur_frame == anim.frames):
-                    ind = np.where(cur_frame == anim.frames)[0][0]
-                    text.data.body = data[ind]
-
-                else:
-                    ind = np.where((cur_frame - anim.frames) == min(cur_frame - anim.frames))[0][0]
-                    text.data.body = ('{0:.'+str(fix_place)+'f}').format(data[ind]) + ' ' + label
+                ind = np.where(abs(cur_frame - anim.frames)  == min(abs(cur_frame - anim.frames)))[0][0]
+                text.data.body = data[ind]
 
         def register():
             bpy.app.handlers.frame_change_post.append(update)
